# climax

[![Build status](https://github.com/miguelgrinberg/climax/workflows/build/badge.svg)](https://github.com/miguelgrinberg/climax/actions) [![codecov](https://codecov.io/gh/miguelgrinberg/climax/branch/main/graph/badge.svg)](https://codecov.io/gh/miguelgrinberg/climax)

A lightweight argparse wrapper inspired by click.

Climax is a little argparse wrapper, with a decorator based syntax heavily
inspired by Armin Ronacher's [click](http://click.pocoo.org/). Climax can
import native argparse parsers as sub-commands, and can also export itself as
a native parser, providing full interoperability with existing argparse
based solutions.

## Resources

- [Documentation](http://climax.readthedocs.io/en/latest/)
- [PyPI](https://pypi.python.org/pypi/climax)
- [Change Log](https://github.com/miguelgrinberg/climax/blob/main/CHANGES.md)
